@@ -5,7 +5,6 @@ import httpx
 from httpx import Response
 from . import GQLException
 
-URL = os.environ["DGRAPH_URL"]
 TIMEOUT = os.getenv("DGRAPH_TIMEOUT", 25.0)
 
 client_sync = httpx.Client(timeout=TIMEOUT)
@@ -33,33 +32,15 @@ def finish(
     return j
 
 
-def gql_sync(
-    query_str: str,
-    variables: dict = None,
-    should_print: bool = False,
-    url: T.Optional[str] = None,
-) -> dict:
-    start = time.time()
-    response = client_sync.post(
-        url=url or URL, json={"query": query_str, "variables": variables or {}}
-    )
-    return finish(
-        response=response,
-        query_str=query_str,
-        should_print=should_print,
-        start_time=start,
-    )
-
-
 async def gql(
+    url: str,
     query_str: str,
     variables: dict = None,
     should_print: bool = False,
-    url: T.Optional[str] = None,
 ) -> dict:
     start = time.time()
     response = await client.post(
-        url=url or URL, json={"query": query_str, "variables": variables or {}}
+        url=url, json={"query": query_str, "variables": variables or {}}
     )
     return finish(
         response=response,
