@@ -303,8 +303,14 @@ def _build_inputs(
                     python_line = python_line.replace(
                         str(pure_type), f"Strawberry.{pure_type}"
                     )
-                ending = "" if "..." in python_line else " = None"
-                python_line = f'{python_line[:python_line.index(" =")]}{ending}'
+                    python_line = (
+                        python_line.replace("Field", "strawberry.field")
+                        .replace("alias=", "name=")
+                        .replace("None", "default=None")
+                        .replace("...", "")
+                    )
+                # ending = "" if "..." in python_line else " = None"
+                # python_line = f'{python_line[:python_line.index(" =")]}{ending}'
             field_str_lst.append(python_line)
         if for_strawberry:
             # sort field_str_lst for straw putting required fields first
